==> SyL-0.14.3.tar.gz: SyL/include/framework/Adm/Flow/SyL_AdmFlowDel.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.5 2007/10/15 13:56:43 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * եδ쥯饹
 */
require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';

/**
 * ե饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.5 2007/10/15 13:56:43 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_AdmFlowDel extends SyL_AdmFlow
{
    /**
     * ڥ졼̾
     *
     * @access protected
     * @var string
     */
    var $opp_name = 'del';

    /**
     * 󥹥ȥ饯
     *
     * @access public
     */
    function SyL_AdmFlowDel()
    {
        parent::SyL_AdmFlow();
    }

    /**
     * ե
     *
     * @access public
     * @param object ǡ֥
     * @param object ƥȴ֥
     */
    function execute(&$data, &$context)
    {
        if ($context->isPost()) {
            // ե
            $form =& $this->getForm();
            // 祭ѥ᡼̾
            $key_name = $form->getStructConfig('key_name');
            // ѥ᡼
            $keys = $data->geta($key_name);
            // ѥ᡼å
            if (!$keys) {
                SyL_Response::redirect($this->getUrl('lst'));
            }

            // DB³
            $conn =& $this->getDB();
            // ADM֥Ⱥ
            $adm  =& SyL_Adm::factory($form, $conn, $keys);
            // ơ֥
            $adm->loadConfig();
            // å
            if (!$adm->isDel()) {
                // Բ
                SyL_Response::redirect($this->getUrl('lst'));
            }
            // ȥ󥶥󳫻
            $conn->beginTransaction();
            // ¹
            $adm->delete();
            // ȥ󥶥
            $conn->commit();
            // DB³λ
            $this->closeDB($conn);

            // λ̤إ쥯
            SyL_Response::redirect($this->getUrl('fin') . '?__adm=del');
        } else {
            SyL_Response::redirect($this->getUrl('lst'));
        }
    }
}

?>

==> SyL-0.14.4.tar.gz: SyL/include/framework/Adm/Flow/SyL_AdmFlowDel.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.6 2007/11/04 13:44:14 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * եδ쥯饹
 */
require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';

/**
 * ե饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.6 2007/11/04 13:44:14 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_AdmFlowDel extends SyL_AdmFlow
{
    /**
     * ڥ졼̾
     *
     * @access protected
     * @var string
     */
    var $opp_name = 'del';

    /**
     * 󥹥ȥ饯
     *
     * @access public
     */
    function SyL_AdmFlowDel()
    {
        parent::SyL_AdmFlow();
    }

    /**
     * ե
     *
     * @access public
     * @param object ǡ֥
     * @param object ƥȴ֥
     */
    function execute(&$data, &$context)
    {
        if ($context->isPost()) {
            // ե
            $form =& $this->getForm();
            // 祭ѥ᡼̾
            $key_name = $form->getStructConfig('key_name');
            // ѥ᡼
            $keys = $data->geta($key_name);
            // ѥ᡼å
            if (!$keys) {
                SyL_Response::redirect($this->getUrl('lst'));
            }

            // DB³
            $conn =& $this->getDB();
            // ADM֥Ⱥ
            $adm  =& SyL_Adm::factory($form, $conn, $keys);
            // ơ֥
            $adm->loadConfig();
            // å
            if (!$adm->isDel()) {
                // Բ
                SyL_Response::redirect($this->getUrl('lst'));
            }
            // ȥ󥶥󳫻
            $conn->beginTransaction();
            // ¹
            $this->delete($adm);
            // ȥ󥶥
            $conn->commit();
            // DB³λ
            $this->closeDB($conn);

            // λ̤إ쥯
            SyL_Response::redirect($this->getUrl('fin') . '?adm_action=del');
        } else {
            SyL_Response::redirect($this->getUrl('lst'));
        }
    }

    /**
     * ¹
     *
     * @access public
     * @param object ADM֥
     */
    function delete(&$adm)
    {
        $adm->delete();
    }
}

?>
